@@ -1,6 +1,6 @@
 # This file is part of Patsy
 # Copyright (C) 2011-2013 Nathaniel Smith <njs@pobox.com>
-# See file COPYING for license information.
+# See file LICENSE.txt for license information.
 
 """patsy is a Python package for describing statistical models and building
 design matrices. It is closely inspired by the 'formula' mini-language used in
@@ -8,13 +8,14 @@ R and S."""
 
 import sys
 
-__version__ = "0.2.1"
+from patsy.version import __version__
 
 # Do this first, to make it easy to check for warnings while testing:
 import os
 if os.environ.get("PATSY_FORCE_NO_WARNINGS"):
     import warnings
     warnings.filterwarnings("error", module="^patsy")
+    warnings.filterwarnings("ignore", "is_categorical_dtype is deprecated", DeprecationWarning, module="^patsy")
     del warnings
 del os
 
@@ -64,7 +65,7 @@ class PatsyError(Exception):
 __all__ = ["PatsyError"]
 
 # We make a rich API available for explicit use. To see what exactly is
-# exported, check each module's __all__, or import this moduel and look at its
+# exported, check each module's __all__, or import this module and look at its
 # __all__.
 
 def _reexport(mod):
@@ -110,5 +111,8 @@ _reexport(patsy.missing)
 import patsy.splines
 _reexport(patsy.splines)
 
+import patsy.mgcv_cubic_splines
+_reexport(patsy.mgcv_cubic_splines)
+
 # XX FIXME: we aren't exporting any of the explicit parsing interface
 # yet. Need to figure out how to do that.
